# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .general_function import GeneralFunction as GeneralFunction_e2280d25


class SubTotalColumn(object):
    """
    Struct Class

    describes how a single data column is treated when creating subtotals.

    See Also:
        `API SubTotalColumn <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1SubTotalColumn.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.SubTotalColumn'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.SubTotalColumn'
    """Literal Constant ``com.sun.star.sheet.SubTotalColumn``"""

    def __init__(self, Column: typing.Optional[int] = 0, Function: typing.Optional[GeneralFunction_e2280d25] = GeneralFunction_e2280d25.NONE) -> None:
        """
        Constructor

        Arguments:
            Column (int, optional): Column value.
            Function (GeneralFunction, optional): Function value.
        """
        super().__init__()

        if isinstance(Column, SubTotalColumn):
            oth: SubTotalColumn = Column
            self.Column = oth.Column
            self.Function = oth.Function
            return

        kargs = {
            "Column": Column,
            "Function": Function,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._column = kwargs["Column"]
        self._function = kwargs["Function"]


    @property
    def Column(self) -> int:
        """
        the index of the column inside the source data area.
        """
        return self._column

    @Column.setter
    def Column(self, value: int) -> None:
        self._column = value

    @property
    def Function(self) -> GeneralFunction_e2280d25:
        """
        specifies what kind of subtotals are calculated.
        """
        return self._function

    @Function.setter
    def Function(self, value: GeneralFunction_e2280d25) -> None:
        self._function = value


__all__ = ['SubTotalColumn']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.xpath
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..dom.x_node_list import XNodeList as XNodeList_ae540b41
    from com.sun.star.xml.xpath.XPathObjectType import XPathObjectTypeProto  # type: ignore

class XXPathObject(XInterface_8f010a43):
    """

    See Also:
        `API XXPathObject <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1xpath_1_1XXPathObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.xpath'
    __ooo_full_ns__: str = 'com.sun.star.xml.xpath.XXPathObject'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.xpath.XXPathObject'

    @abstractmethod
    def getBoolean(self) -> bool:
        """
        get value of a boolean object
        """
        ...
    @abstractmethod
    def getByte(self) -> int:
        """
        get number as byte
        """
        ...
    @abstractmethod
    def getDouble(self) -> float:
        """
        get number as double
        """
        ...
    @abstractmethod
    def getFloat(self) -> float:
        """
        get number as float
        """
        ...
    @abstractmethod
    def getHyper(self) -> int:
        """
        get number as hyper
        """
        ...
    @abstractmethod
    def getLong(self) -> int:
        """
        get number as long
        """
        ...
    @abstractmethod
    def getNodeList(self) -> XNodeList_ae540b41:
        """
        get the nodes from a node list type object
        """
        ...
    @abstractmethod
    def getObjectType(self) -> XPathObjectTypeProto:
        """
        get object type
        """
        ...
    @abstractmethod
    def getShort(self) -> int:
        """
        get number as short
        """
        ...
    @abstractmethod
    def getString(self) -> str:
        """
        get string value
        """
        ...

__all__ = ['XXPathObject']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_accessible import XAccessible as XAccessible_1cbc0eb6

class XAccessibleSelection(XInterface_8f010a43):
    """
    Implement this interface to represent a selection of accessible objects.
    
    This interface is the standard mechanism to obtain and modify the currently selected children. Every object that has children that can be selected should support this interface.
    
    The XAccessibleSelection interface has to be implemented in conjunction with the XAccessibleContext interface that provides the children on which the first operates.
    
    It depends on the class implementing this interface, whether it supports single or multi selection.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleSelection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleSelection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.XAccessibleSelection'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.accessibility.XAccessibleSelection'

    @abstractmethod
    def clearAccessibleSelection(self) -> None:
        """
        Clears the selection, so that no children of the object are selected.
        """
        ...
    @abstractmethod
    def deselectAccessibleChild(self, nChildIndex: int) -> None:
        """
        Removes the specified child from the set of this object's selected children.
        
        Note that not all applications support deselection: calls to this method may be silently ignored.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getSelectedAccessibleChild(self, nSelectedChildIndex: int) -> XAccessible_1cbc0eb6:
        """
        Returns the specified selected Accessible child.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getSelectedAccessibleChildCount(self) -> int:
        """
        Returns the number of Accessible children that are currently selected.
        
        This number specifies the valid interval of indices that can be used as arguments for the method XAccessibleSelection.getSelectedAccessibleChild().
        """
        ...
    @abstractmethod
    def isAccessibleChildSelected(self, nChildIndex: int) -> bool:
        """
        Determines if the specified child of this object is selected.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def selectAccessibleChild(self, nChildIndex: int) -> None:
        """
        Selects the specified Accessible child of the object.
        
        Depending on the implementing class the child is added to the current set a selected children (multi selection) or a previously selected child is deselected first (single selection).

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def selectAllAccessibleChildren(self) -> None:
        """
        Select all children.
        
        Causes every child of the object to be selected if the object supports multiple selections. If multiple selection is not supported then the first child, if it exists, is selected and all other children are deselected.
        """
        ...

__all__ = ['XAccessibleSelection']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb.tools
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_connection_supplier import XConnectionSupplier as XConnectionSupplier_57f3105c
if typing.TYPE_CHECKING:
    from ...beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XViewAccess(XConnectionSupplier_57f3105c):
    """
    allows to fetch and to change the sql statements of views
    
    **since**
    
        OOo 3.3

    See Also:
        `API XViewAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XViewAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb.tools'
    __ooo_full_ns__: str = 'com.sun.star.sdb.tools.XViewAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.tools.XViewAccess'

    @abstractmethod
    def alterCommand(self, view: XPropertySet_bc180bfa, command: str) -> None:
        """
        allows to alter the SQL statement of a view

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getCommand(self, view: XPropertySet_bc180bfa) -> str:
        """
        returns the SQL statement of the view

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...

__all__ = ['XViewAccess']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..beans.x_property_container import XPropertyContainer as XPropertyContainer_c600e71
    from ..embed.x_storage import XStorage as XStorage_8e460a32
    from ..lang.locale import Locale as Locale_70d308fa
    from ..util.date_time import DateTime as DateTime_84de09d3

class XDocumentProperties(ABC):
    """
    provides document-specific information such as the author, creation date, and user-defined fields.
    
    This interface manages access to document meta-data properties. Such properties may be set from the outside via the setter methods (e.g. when importing arbitrary document formats that support document properties), or imported from an ODF package via the methods loadFromStorage() and loadFromMedium(). The properties may also be stored via the methods storeToStorage() and storeToMedium().
    
    **since**
    
        OOo 3.0

    See Also:
        `API XDocumentProperties <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XDocumentProperties'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XDocumentProperties'

    @abstractmethod
    def getUserDefinedProperties(self) -> XPropertyContainer_c600e71:
        """
        provides access to a container for user-defined properties.
        
        The returned object also implements the interface com.sun.star.beans.XPropertySet.
        """
        ...
    @abstractmethod
    def loadFromMedium(self, URL: str, Medium: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        loads document properties from an ODF package or an OLE container.
        
        The URL could be part of the Medium parameter, but because often no other parameters except the URL are needed, providing it separately was added for convenience.

        Raises:
            com.sun.star.io.WrongFormatException: ``WrongFormatException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def loadFromStorage(self, Storage: XStorage_8e460a32, Medium: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        loads document properties from an ODF package.
        
        This method is used for accessing an ODF package that is owned by someone else, e.g., a document.
        
        This is unfortunately necessary in order to properly resolve relative URLs in the meta-data.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.WrongFormatException: ``WrongFormatException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def resetUserData(self, Author: str) -> None:
        """
        resets all attributes that could identify the user.
        
        Clears the document properties, such that it appears the document has just been created. This is a convenience method which resets several attributes at once, as follows:
        """
        ...
    @abstractmethod
    def storeToMedium(self, URL: str, Medium: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        stores document properties to an ODF package or an OLE container.
        
        The URL could be part of the Medium parameter, but because often no other parameters except the URL are needed, providing it separately was added for convenience.

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def storeToStorage(self, Storage: XStorage_8e460a32, Medium: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        stores document properties to an ODF package.
        
        This method is used for accessing an ODF package that is owned by someone else, e.g., a document. Note that the implementation may choose to store the meta-data in either OOo or ODF format, depending on the MediaType property of the given Storage argument.
        
        This is unfortunately necessary in order to properly resolve relative URLs in the meta-data.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractproperty
    def DocumentStatistics(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        contains some statistics about the document.
        
        The contained statistics may be specific to the type of the document.
        """
        ...

    @abstractproperty
    def Keywords(self) -> typing.Tuple[str, ...]:
        """
        contains a list of keywords for the document.
        """
        ...

    @abstractproperty
    def Author(self) -> str:
        """
        contains the initial author of the document.
        """
        ...

    @abstractproperty
    def AutoloadSecs(self) -> int:
        """
        contains the number of seconds after which a specified URL is to be loaded after the document is loaded into a desktop frame.
        
        A value of 0 is valid and describes a redirection. A value of 0 together with an empty string as AutoloadURL describes a case where no autoload is specified.
        """
        ...

    @abstractproperty
    def AutoloadURL(self) -> str:
        """
        contains the URL to load automatically at a specified time after the document is loaded into a desktop frame.
        
        An empty URL is valid and describes a case where the document shall be reloaded from its original location after some time described by the attribute AutoloadSecs. An empty string together with an AutoloadSecs value of 0 describes a case where no autoload is specified.
        """
        ...

    @abstractproperty
    def CreationDate(self) -> DateTime_84de09d3:
        """
        contains the date and time when the document was created.
        """
        ...

    @abstractproperty
    def DefaultTarget(self) -> str:
        """
        contains the name of the default frame into which links should be loaded if no target is specified.
        
        This applies to the autoload feature too, but to others as well.
        """
        ...

    @abstractproperty
    def Description(self) -> str:
        """
        contains a multi-line comment describing the document.
        
        Line delimiters can be UNIX, Macintosh or DOS style.
        """
        ...

    @abstractproperty
    def EditingCycles(self) -> int:
        """
        describes how often the document was edited and saved.
        """
        ...

    @abstractproperty
    def EditingDuration(self) -> int:
        """
        contains the net time of editing the document (in seconds).
        """
        ...

    @abstractproperty
    def Generator(self) -> str:
        """
        identifies which application was used to create or last modify the document.
        
        The generating application will set this attribute when it creates a new document or it saves a document. When a document is loaded that itself contains such an attribute it will be preserved until the document is saved again.
        """
        ...

    @abstractproperty
    def Language(self) -> Locale_70d308fa:
        """
        contains the default language of the document.
        """
        ...

    @abstractproperty
    def ModificationDate(self) -> DateTime_84de09d3:
        """
        contains the date and time of the last time the document was stored.
        
        If the document has never been stored, contains a default value.
        """
        ...

    @abstractproperty
    def ModifiedBy(self) -> str:
        """
        contains the name of the person who most recently stored the document.
        """
        ...

    @abstractproperty
    def PrintDate(self) -> DateTime_84de09d3:
        """
        contains the date and time when the document was last printed.
        
        If the document has never been printed, contains a default value.
        """
        ...

    @abstractproperty
    def PrintedBy(self) -> str:
        """
        contains the name of the person who most recently printed the document.
        """
        ...

    @abstractproperty
    def Subject(self) -> str:
        """
        contains the subject of the document.
        """
        ...

    @abstractproperty
    def TemplateDate(self) -> DateTime_84de09d3:
        """
        contains the date and time of when the document was created or updated from the template.
        """
        ...

    @abstractproperty
    def TemplateName(self) -> str:
        """
        contains the name of the template from which the document was created.
        
        The value is an empty string if the document was not created from a template or if it was detached from the template.
        """
        ...

    @abstractproperty
    def TemplateURL(self) -> str:
        """
        contains the URL of the template from which the document was created.
        
        The value is an empty string if the document was not created from a template or if it was detached from the template.
        """
        ...

    @abstractproperty
    def Title(self) -> str:
        """
        contains the title of the document.
        """
        ...


__all__ = ['XDocumentProperties']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .x_actions_approval import XActionsApproval as XActionsApproval_ed4b0d73
    from ..uno.x_interface import XInterface as XInterface_8f010a43

class InstanceLocker(XComponent_98dc0ab5):
    """
    Service Class

    The main task of this service is to prevent closing, terminating and/or etc.
    
    of controlled object.
    
    After creation the service adds a listener of requested type ( close, terminate and/or etc. ) to the controlled object and let the listener throw related veto exception until the service is disposed.

    See Also:
        `API InstanceLocker <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1embed_1_1InstanceLocker.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.InstanceLocker'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def InstanceLockerCtor1(self, xInstance: XInterface_8f010a43, nActions: int) -> None:
        """
        is used to initialize the object on it's creation.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.frame.DoubleInitializationException: ``DoubleInitializationException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def InstanceLockerCtor2(self, xInstance: XInterface_8f010a43, nActions: int, xApprove: XActionsApproval_ed4b0d73) -> None:
        """
        is used to initialize the object on it's creation.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.frame.DoubleInitializationException: ``DoubleInitializationException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['InstanceLocker']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2.data
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_labeled_data_sequence import XLabeledDataSequence as XLabeledDataSequence_7e1a10c8

class XDataSource(XInterface_8f010a43):
    """
    provides access to sequences of data.
    
    With this interface data can only be read from.
    
    If the data stored consists only of floating point numbers (double values), the returned instances should also support the service NumericalDataSequence.
    
    If the data stored consists only of strings, the returned instances should also support the service TextualDataSequence.

    See Also:
        `API XDataSource <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XDataSource.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2.data'
    __ooo_full_ns__: str = 'com.sun.star.chart2.data.XDataSource'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.data.XDataSource'

    @abstractmethod
    def getDataSequences(self) -> typing.Tuple[XLabeledDataSequence_7e1a10c8, ...]:
        """
        returns data sequences.
        
        If the data stored consist only of floating point numbers (double values), the returned instances should also support the service NumericalDataSequence.
        
        If the data stored consist only of strings, the returned instances should also support the service TextualDataSequence.
        """
        ...

__all__ = ['XDataSource']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XResultSet(XInterface_8f010a43):
    """
    provides the navigation on a table of data.
    
    A com.sun.star.sdbc.ResultSet object is usually generated by executing a com.sun.star.sdbc.Statement.
    
    A ResultSet maintains a cursor pointing to its current row of data. Initially the cursor is positioned before the first row. The \"next\" method moves the cursor to the next row.

    See Also:
        `API XResultSet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XResultSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XResultSet'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XResultSet'

    @abstractmethod
    def absolute(self, row: int) -> bool:
        """
        moves the cursor to the given row number in the result set.
        
        If the row number is positive, the cursor moves to the given row number with respect to the beginning of the result set. The first row is row 1, the second is row 2, and so on.
        
        If the given row number is negative, the cursor moves to an absolute row position with respect to the end of the result set. For example, calling absolute(-1) positions the cursor on the last row, absolute(-2) indicates the next-to-last row, and so on.
        
        An attempt to position the cursor beyond the first/last row in the result set leaves the cursor before/after the first/last row, respectively.
        
        Note: Calling absolute(1) is the same as calling com.sun.star.sdbc.XResultSet.first(). Calling moveToPosition(-1) is the same as calling moveToLast().

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def afterLast(self) -> None:
        """
        moves the cursor to the end of the result set, just after the last row.
        
        Has no effect if the result set contains no rows.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def beforeFirst(self) -> None:
        """
        moves the cursor to the front of the result set, just before the first row.
        
        Has no effect if the result set contains no rows.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def first(self) -> bool:
        """
        moves the cursor to the first row in the result set.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getRow(self) -> int:
        """
        retrieves the current row number.
        
        The first row is number 1, the second number 2, and so on.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getStatement(self) -> XInterface_8f010a43:
        """
        returns the Statement that produced this com.sun.star.sdbc.ResultSet object.
        
        If the result set was generated some other way, such as by an com.sun.star.sdbc.XDatabaseMetaData method, this method returns NULL.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isAfterLast(self) -> bool:
        """
        indicates whether the cursor is after the last row in the result set.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isBeforeFirst(self) -> bool:
        """
        indicates whether the cursor is before the first row in the result set.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isFirst(self) -> bool:
        """
        indicates whether the cursor is on the first row of the result set.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isLast(self) -> bool:
        """
        indicates whether the cursor is on the last row of the result set.
        
        Note:  Calling the method isAtLast may be expensive because the SDBC driver might need to fetch ahead one row in order to determine whether the current row is the last row in the result set.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def last(self) -> bool:
        """
        moves the cursor to the last row in the result set.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def next(self) -> bool:
        """
        moves the cursor down one row from its current position.
        
        A ResultSet cursor is initially positioned before the first row; the first call to next makes the first row the current row; the second call makes the second row the current row, and so on.
        
        If an input stream is open for the current row, a call to the method next will implicitly close it. The ResultSet's warning chain is cleared when a new row is read.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def previous(self) -> bool:
        """
        moves the cursor to the previous row in the result set.
        
        Note: previous() is not the same as relative(-1) because it makes sense to call previous() when there is no current row.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def refreshRow(self) -> None:
        """
        refreshes the current row with its most recent value in the database.
        
        Cannot be called when on the insert row. The refreshRow method provides a way for an application to explicitly tell the SDBC driver to refetch a row(s) from the database. An application may want to call refreshRow when caching or prefetching is being done by the SDBC driver to fetch the latest value of a row from the database. The SDBC driver may actually refresh multiple rows at once if the fetch size is greater than one. All values are refetched subject to the transaction isolation level and cursor sensitivity. If refreshRow is called after calling updateXXX , but before calling com.sun.star.sdbc.XResultSet.updateRow() , then the updates made to the row are lost. Calling the method refreshRow frequently will likely slow performance.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def relative(self, rows: int) -> bool:
        """
        moves the cursor a relative number of rows, either positive or negative.
        
        Attempting to move beyond the first/last row in the result set positions the cursor before/after the first/last row. Calling relative(0) is valid, but does not change the cursor position.
        
        Note: Calling relative(1) is different from calling com.sun.star.sdbc.XResultSet.next() because is makes sense to call next() when there is no current row, for example, when the cursor is positioned before the first row or after the last row of the result set.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def rowDeleted(self) -> bool:
        """
        indicates whether a row has been deleted.
        
        A deleted row may leave a visible \"hole\" in a result set. This method can be used to detect holes in a result set. The value returned depends on whether or not the result set can detect deletions.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def rowInserted(self) -> bool:
        """
        indicates whether the current row has had an insertion.
        
        The value returned depends on whether or not the result set can detect visible inserts.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def rowUpdated(self) -> bool:
        """
        indicates whether the current row has been updated.
        
        The value returned depends on whether or not the result set can detect updates.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XResultSet']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XPrinterPropertySet(XPropertySet_bc180bfa):
    """
    represents an extended property set for printer properties.
    
    All properties are vetoable properties. If you change the properties between com.sun.star.awt.XPrinter.startPage() and com.sun.star.awt.XPrinter.endPage(), a com.sun.star.beans.PropertyVetoException is thrown.

    See Also:
        `API XPrinterPropertySet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XPrinterPropertySet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XPrinterPropertySet'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XPrinterPropertySet'

    @abstractmethod
    def getBinarySetup(self) -> uno.ByteSequence:
        """
        returns a binary encoded version of the printer setup.
        """
        ...
    @abstractmethod
    def getFormDescriptions(self) -> typing.Tuple[str, ...]:
        """
        returns descriptions of all available printer forms.
        """
        ...
    @abstractmethod
    def selectForm(self, aFormDescription: str) -> None:
        """
        sets the form that should be used.
        
        Indirectly a printer is selected.

        Raises:
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setBinarySetup(self, data: uno.ByteSequence) -> None:
        """
        sets the data specific to the printer driver.
        
        Get this data from the info printer and set the data to the printer.

        Raises:
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setHorizontal(self, bHorizontal: bool) -> None:
        """
        sets the orientation.

        Raises:
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XPrinterPropertySet']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.sheet.accessible_cell import AccessibleCell as AccessibleCell
with suppress(ImportError):
    from ...dyn.sheet.accessible_csv_cell import AccessibleCsvCell as AccessibleCsvCell
with suppress(ImportError):
    from ...dyn.sheet.accessible_csv_ruler import AccessibleCsvRuler as AccessibleCsvRuler
with suppress(ImportError):
    from ...dyn.sheet.accessible_csv_table import AccessibleCsvTable as AccessibleCsvTable
with suppress(ImportError):
    from ...dyn.sheet.accessible_page_header_footer_areas_view import AccessiblePageHeaderFooterAreasView as AccessiblePageHeaderFooterAreasView
with suppress(ImportError):
    from ...dyn.sheet.accessible_spreadsheet import AccessibleSpreadsheet as AccessibleSpreadsheet
with suppress(ImportError):
    from ...dyn.sheet.accessible_spreadsheet_document_view import AccessibleSpreadsheetDocumentView as AccessibleSpreadsheetDocumentView
with suppress(ImportError):
    from ...dyn.sheet.accessible_spreadsheet_page_view import AccessibleSpreadsheetPageView as AccessibleSpreadsheetPageView
with suppress(ImportError):
    from ...dyn.sheet.activation_event import ActivationEvent as ActivationEvent
with suppress(ImportError):
    from ...dyn.sheet.add_in import AddIn as AddIn
with suppress(ImportError):
    from ...dyn.sheet.address_convention import AddressConvention as AddressConvention
with suppress(ImportError):
    from ...dyn.sheet.address_convention import AddressConventionEnum as AddressConventionEnum
with suppress(ImportError):
    from ...dyn.sheet.border import Border as Border
with suppress(ImportError):
    from ...dyn.sheet.cell_annotation import CellAnnotation as CellAnnotation
with suppress(ImportError):
    from ...dyn.sheet.cell_annotation_shape import CellAnnotationShape as CellAnnotationShape
with suppress(ImportError):
    from ...dyn.sheet.cell_annotations import CellAnnotations as CellAnnotations
with suppress(ImportError):
    from ...dyn.sheet.cell_annotations_enumeration import CellAnnotationsEnumeration as CellAnnotationsEnumeration
with suppress(ImportError):
    from ...dyn.sheet.cell_area_link import CellAreaLink as CellAreaLink
with suppress(ImportError):
    from ...dyn.sheet.cell_area_links import CellAreaLinks as CellAreaLinks
with suppress(ImportError):
    from ...dyn.sheet.cell_area_links_enumeration import CellAreaLinksEnumeration as CellAreaLinksEnumeration
with suppress(ImportError):
    from ...dyn.sheet.cell_delete_mode import CellDeleteMode as CellDeleteMode
with suppress(ImportError):
    from ...dyn.sheet.cell_flags import CellFlags as CellFlags
with suppress(ImportError):
    from ...dyn.sheet.cell_flags import CellFlagsEnum as CellFlagsEnum
with suppress(ImportError):
    from ...dyn.sheet.cell_format_ranges import CellFormatRanges as CellFormatRanges
with suppress(ImportError):
    from ...dyn.sheet.cell_format_ranges_enumeration import CellFormatRangesEnumeration as CellFormatRangesEnumeration
with suppress(ImportError):
    from ...dyn.sheet.cell_insert_mode import CellInsertMode as CellInsertMode
with suppress(ImportError):
    from ...dyn.sheet.cells import Cells as Cells
with suppress(ImportError):
    from ...dyn.sheet.cells_enumeration import CellsEnumeration as CellsEnumeration
with suppress(ImportError):
    from ...dyn.sheet.color_scale import ColorScale as ColorScale
with suppress(ImportError):
    from ...dyn.sheet.color_scale_entry_type import ColorScaleEntryType as ColorScaleEntryType
with suppress(ImportError):
    from ...dyn.sheet.color_scale_entry_type import ColorScaleEntryTypeEnum as ColorScaleEntryTypeEnum
with suppress(ImportError):
    from ...dyn.sheet.complex_reference import ComplexReference as ComplexReference
with suppress(ImportError):
    from ...dyn.sheet.condition_entry_type import ConditionEntryType as ConditionEntryType
with suppress(ImportError):
    from ...dyn.sheet.condition_entry_type import ConditionEntryTypeEnum as ConditionEntryTypeEnum
with suppress(ImportError):
    from ...dyn.sheet.condition_format_entry import ConditionFormatEntry as ConditionFormatEntry
with suppress(ImportError):
    from ...dyn.sheet.condition_format_operator import ConditionFormatOperator as ConditionFormatOperator
with suppress(ImportError):
    from ...dyn.sheet.condition_format_operator import ConditionFormatOperatorEnum as ConditionFormatOperatorEnum
with suppress(ImportError):
    from ...dyn.sheet.condition_operator import ConditionOperator as ConditionOperator
with suppress(ImportError):
    from ...dyn.sheet.condition_operator2 import ConditionOperator2 as ConditionOperator2
with suppress(ImportError):
    from ...dyn.sheet.condition_operator2 import ConditionOperator2Enum as ConditionOperator2Enum
with suppress(ImportError):
    from ...dyn.sheet.conditional_format import ConditionalFormat as ConditionalFormat
with suppress(ImportError):
    from ...dyn.sheet.consolidation_descriptor import ConsolidationDescriptor as ConsolidationDescriptor
with suppress(ImportError):
    from ...dyn.sheet.dde_item_info import DDEItemInfo as DDEItemInfo
with suppress(ImportError):
    from ...dyn.sheet.dde_link import DDELink as DDELink
with suppress(ImportError):
    from ...dyn.sheet.dde_link_info import DDELinkInfo as DDELinkInfo
with suppress(ImportError):
    from ...dyn.sheet.dde_link_mode import DDELinkMode as DDELinkMode
with suppress(ImportError):
    from ...dyn.sheet.dde_links import DDELinks as DDELinks
with suppress(ImportError):
    from ...dyn.sheet.dde_links_enumeration import DDELinksEnumeration as DDELinksEnumeration
with suppress(ImportError):
    from ...dyn.sheet.data_bar import DataBar as DataBar
with suppress(ImportError):
    from ...dyn.sheet.data_bar_axis import DataBarAxis as DataBarAxis
with suppress(ImportError):
    from ...dyn.sheet.data_bar_axis import DataBarAxisEnum as DataBarAxisEnum
with suppress(ImportError):
    from ...dyn.sheet.data_bar_entry_type import DataBarEntryType as DataBarEntryType
with suppress(ImportError):
    from ...dyn.sheet.data_bar_entry_type import DataBarEntryTypeEnum as DataBarEntryTypeEnum
with suppress(ImportError):
    from ...dyn.sheet.data_import_mode import DataImportMode as DataImportMode
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_descriptor import DataPilotDescriptor as DataPilotDescriptor
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field import DataPilotField as DataPilotField
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_auto_show_info import DataPilotFieldAutoShowInfo as DataPilotFieldAutoShowInfo
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_filter import DataPilotFieldFilter as DataPilotFieldFilter
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_group import DataPilotFieldGroup as DataPilotFieldGroup
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_group_by import DataPilotFieldGroupBy as DataPilotFieldGroupBy
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_group_by import DataPilotFieldGroupByEnum as DataPilotFieldGroupByEnum
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_group_enumeration import DataPilotFieldGroupEnumeration as DataPilotFieldGroupEnumeration
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_group_info import DataPilotFieldGroupInfo as DataPilotFieldGroupInfo
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_group_item import DataPilotFieldGroupItem as DataPilotFieldGroupItem
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_groups import DataPilotFieldGroups as DataPilotFieldGroups
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_groups_enumeration import DataPilotFieldGroupsEnumeration as DataPilotFieldGroupsEnumeration
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_layout_info import DataPilotFieldLayoutInfo as DataPilotFieldLayoutInfo
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_layout_mode import DataPilotFieldLayoutMode as DataPilotFieldLayoutMode
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_layout_mode import DataPilotFieldLayoutModeEnum as DataPilotFieldLayoutModeEnum
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_orientation import DataPilotFieldOrientation as DataPilotFieldOrientation
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_reference import DataPilotFieldReference as DataPilotFieldReference
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_reference_item_type import DataPilotFieldReferenceItemType as DataPilotFieldReferenceItemType
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_reference_item_type import DataPilotFieldReferenceItemTypeEnum as DataPilotFieldReferenceItemTypeEnum
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_reference_type import DataPilotFieldReferenceType as DataPilotFieldReferenceType
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_reference_type import DataPilotFieldReferenceTypeEnum as DataPilotFieldReferenceTypeEnum
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_show_items_mode import DataPilotFieldShowItemsMode as DataPilotFieldShowItemsMode
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_show_items_mode import DataPilotFieldShowItemsModeEnum as DataPilotFieldShowItemsModeEnum
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_sort_info import DataPilotFieldSortInfo as DataPilotFieldSortInfo
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_sort_mode import DataPilotFieldSortMode as DataPilotFieldSortMode
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_field_sort_mode import DataPilotFieldSortModeEnum as DataPilotFieldSortModeEnum
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_fields import DataPilotFields as DataPilotFields
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_fields_enumeration import DataPilotFieldsEnumeration as DataPilotFieldsEnumeration
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_item import DataPilotItem as DataPilotItem
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_items import DataPilotItems as DataPilotItems
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_items_enumeration import DataPilotItemsEnumeration as DataPilotItemsEnumeration
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_output_range_type import DataPilotOutputRangeType as DataPilotOutputRangeType
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_output_range_type import DataPilotOutputRangeTypeEnum as DataPilotOutputRangeTypeEnum
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_source import DataPilotSource as DataPilotSource
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_source_dimension import DataPilotSourceDimension as DataPilotSourceDimension
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_source_dimensions import DataPilotSourceDimensions as DataPilotSourceDimensions
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_source_hierarchies import DataPilotSourceHierarchies as DataPilotSourceHierarchies
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_source_hierarchy import DataPilotSourceHierarchy as DataPilotSourceHierarchy
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_source_level import DataPilotSourceLevel as DataPilotSourceLevel
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_source_levels import DataPilotSourceLevels as DataPilotSourceLevels
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_source_member import DataPilotSourceMember as DataPilotSourceMember
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_source_members import DataPilotSourceMembers as DataPilotSourceMembers
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_table import DataPilotTable as DataPilotTable
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_table_header_data import DataPilotTableHeaderData as DataPilotTableHeaderData
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_table_position_data import DataPilotTablePositionData as DataPilotTablePositionData
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_table_position_type import DataPilotTablePositionType as DataPilotTablePositionType
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_table_position_type import DataPilotTablePositionTypeEnum as DataPilotTablePositionTypeEnum
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_table_result_data import DataPilotTableResultData as DataPilotTableResultData
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_tables import DataPilotTables as DataPilotTables
with suppress(ImportError):
    from ...dyn.sheet.data_pilot_tables_enumeration import DataPilotTablesEnumeration as DataPilotTablesEnumeration
with suppress(ImportError):
    from ...dyn.sheet.data_result import DataResult as DataResult
with suppress(ImportError):
    from ...dyn.sheet.data_result_flags import DataResultFlags as DataResultFlags
with suppress(ImportError):
    from ...dyn.sheet.data_result_flags import DataResultFlagsEnum as DataResultFlagsEnum
with suppress(ImportError):
    from ...dyn.sheet.database_import_descriptor import DatabaseImportDescriptor as DatabaseImportDescriptor
with suppress(ImportError):
    from ...dyn.sheet.database_range import DatabaseRange as DatabaseRange
with suppress(ImportError):
    from ...dyn.sheet.database_ranges import DatabaseRanges as DatabaseRanges
with suppress(ImportError):
    from ...dyn.sheet.database_ranges_enumeration import DatabaseRangesEnumeration as DatabaseRangesEnumeration
with suppress(ImportError):
    from ...dyn.sheet.date_condition import DateCondition as DateCondition
with suppress(ImportError):
    from ...dyn.sheet.date_type import DateType as DateType
with suppress(ImportError):
    from ...dyn.sheet.date_type import DateTypeEnum as DateTypeEnum
with suppress(ImportError):
    from ...dyn.sheet.dimension_flags import DimensionFlags as DimensionFlags
with suppress(ImportError):
    from ...dyn.sheet.dimension_flags import DimensionFlagsEnum as DimensionFlagsEnum
with suppress(ImportError):
    from ...dyn.sheet.document_settings import DocumentSettings as DocumentSettings
with suppress(ImportError):
    from ...dyn.sheet.external_doc_link import ExternalDocLink as ExternalDocLink
with suppress(ImportError):
    from ...dyn.sheet.external_doc_links import ExternalDocLinks as ExternalDocLinks
with suppress(ImportError):
    from ...dyn.sheet.external_link_info import ExternalLinkInfo as ExternalLinkInfo
with suppress(ImportError):
    from ...dyn.sheet.external_link_type import ExternalLinkType as ExternalLinkType
with suppress(ImportError):
    from ...dyn.sheet.external_link_type import ExternalLinkTypeEnum as ExternalLinkTypeEnum
with suppress(ImportError):
    from ...dyn.sheet.external_reference import ExternalReference as ExternalReference
with suppress(ImportError):
    from ...dyn.sheet.external_sheet_cache import ExternalSheetCache as ExternalSheetCache
with suppress(ImportError):
    from ...dyn.sheet.fill_date_mode import FillDateMode as FillDateMode
with suppress(ImportError):
    from ...dyn.sheet.fill_direction import FillDirection as FillDirection
with suppress(ImportError):
    from ...dyn.sheet.fill_mode import FillMode as FillMode
with suppress(ImportError):
    from ...dyn.sheet.filter_connection import FilterConnection as FilterConnection
with suppress(ImportError):
    from ...dyn.sheet.filter_field_type import FilterFieldType as FilterFieldType
with suppress(ImportError):
    from ...dyn.sheet.filter_field_type import FilterFieldTypeEnum as FilterFieldTypeEnum
with suppress(ImportError):
    from ...dyn.sheet.filter_field_value import FilterFieldValue as FilterFieldValue
with suppress(ImportError):
    from ...dyn.sheet.filter_formula_parser import FilterFormulaParser as FilterFormulaParser
with suppress(ImportError):
    from ...dyn.sheet.filter_operator import FilterOperator as FilterOperator
with suppress(ImportError):
    from ...dyn.sheet.filter_operator2 import FilterOperator2 as FilterOperator2
with suppress(ImportError):
    from ...dyn.sheet.filter_operator2 import FilterOperator2Enum as FilterOperator2Enum
with suppress(ImportError):
    from ...dyn.sheet.formula_language import FormulaLanguage as FormulaLanguage
with suppress(ImportError):
    from ...dyn.sheet.formula_language import FormulaLanguageEnum as FormulaLanguageEnum
with suppress(ImportError):
    from ...dyn.sheet.formula_map_group import FormulaMapGroup as FormulaMapGroup
with suppress(ImportError):
    from ...dyn.sheet.formula_map_group import FormulaMapGroupEnum as FormulaMapGroupEnum
with suppress(ImportError):
    from ...dyn.sheet.formula_map_group_special_offset import FormulaMapGroupSpecialOffset as FormulaMapGroupSpecialOffset
with suppress(ImportError):
    from ...dyn.sheet.formula_map_group_special_offset import FormulaMapGroupSpecialOffsetEnum as FormulaMapGroupSpecialOffsetEnum
with suppress(ImportError):
    from ...dyn.sheet.formula_op_code_map_entry import FormulaOpCodeMapEntry as FormulaOpCodeMapEntry
with suppress(ImportError):
    from ...dyn.sheet.formula_op_code_mapper import FormulaOpCodeMapper as FormulaOpCodeMapper
with suppress(ImportError):
    from ...dyn.sheet.formula_parser import FormulaParser as FormulaParser
with suppress(ImportError):
    from ...dyn.sheet.formula_result import FormulaResult as FormulaResult
with suppress(ImportError):
    from ...dyn.sheet.formula_result import FormulaResultEnum as FormulaResultEnum
with suppress(ImportError):
    from ...dyn.sheet.formula_token import FormulaToken as FormulaToken
with suppress(ImportError):
    from ...dyn.sheet.function_access import FunctionAccess as FunctionAccess
with suppress(ImportError):
    from ...dyn.sheet.function_argument import FunctionArgument as FunctionArgument
with suppress(ImportError):
    from ...dyn.sheet.function_category import FunctionCategory as FunctionCategory
with suppress(ImportError):
    from ...dyn.sheet.function_category import FunctionCategoryEnum as FunctionCategoryEnum
with suppress(ImportError):
    from ...dyn.sheet.function_description import FunctionDescription as FunctionDescription
with suppress(ImportError):
    from ...dyn.sheet.function_description_enumeration import FunctionDescriptionEnumeration as FunctionDescriptionEnumeration
with suppress(ImportError):
    from ...dyn.sheet.function_descriptions import FunctionDescriptions as FunctionDescriptions
with suppress(ImportError):
    from ...dyn.sheet.general_function import GeneralFunction as GeneralFunction
with suppress(ImportError):
    from ...dyn.sheet.general_function2 import GeneralFunction2 as GeneralFunction2
with suppress(ImportError):
    from ...dyn.sheet.general_function2 import GeneralFunction2Enum as GeneralFunction2Enum
with suppress(ImportError):
    from ...dyn.sheet.global_sheet_settings import GlobalSheetSettings as GlobalSheetSettings
with suppress(ImportError):
    from ...dyn.sheet.goal_result import GoalResult as GoalResult
with suppress(ImportError):
    from ...dyn.sheet.header_footer_content import HeaderFooterContent as HeaderFooterContent
with suppress(ImportError):
    from ...dyn.sheet.icon_set import IconSet as IconSet
with suppress(ImportError):
    from ...dyn.sheet.icon_set_format_entry import IconSetFormatEntry as IconSetFormatEntry
with suppress(ImportError):
    from ...dyn.sheet.icon_set_format_entry import IconSetFormatEntryEnum as IconSetFormatEntryEnum
with suppress(ImportError):
    from ...dyn.sheet.icon_set_type import IconSetType as IconSetType
with suppress(ImportError):
    from ...dyn.sheet.icon_set_type import IconSetTypeEnum as IconSetTypeEnum
with suppress(ImportError):
    from ...dyn.sheet.label_range import LabelRange as LabelRange
with suppress(ImportError):
    from ...dyn.sheet.label_ranges import LabelRanges as LabelRanges
with suppress(ImportError):
    from ...dyn.sheet.label_ranges_enumeration import LabelRangesEnumeration as LabelRangesEnumeration
with suppress(ImportError):
    from ...dyn.sheet.localized_name import LocalizedName as LocalizedName
with suppress(ImportError):
    from ...dyn.sheet.member_result import MemberResult as MemberResult
with suppress(ImportError):
    from ...dyn.sheet.member_result_flags import MemberResultFlags as MemberResultFlags
with suppress(ImportError):
    from ...dyn.sheet.member_result_flags import MemberResultFlagsEnum as MemberResultFlagsEnum
with suppress(ImportError):
    from ...dyn.sheet.move_direction import MoveDirection as MoveDirection
with suppress(ImportError):
    from ...dyn.sheet.move_direction import MoveDirectionEnum as MoveDirectionEnum
with suppress(ImportError):
    from ...dyn.sheet.name_token import NameToken as NameToken
with suppress(ImportError):
    from ...dyn.sheet.named_range import NamedRange as NamedRange
with suppress(ImportError):
    from ...dyn.sheet.named_range_flag import NamedRangeFlag as NamedRangeFlag
with suppress(ImportError):
    from ...dyn.sheet.named_range_flag import NamedRangeFlagEnum as NamedRangeFlagEnum
with suppress(ImportError):
    from ...dyn.sheet.named_ranges import NamedRanges as NamedRanges
with suppress(ImportError):
    from ...dyn.sheet.named_ranges_enumeration import NamedRangesEnumeration as NamedRangesEnumeration
with suppress(ImportError):
    from ...dyn.sheet.no_convergence_exception import NoConvergenceException as NoConvergenceException
with suppress(ImportError):
    from ...dyn.sheet.paste_operation import PasteOperation as PasteOperation
with suppress(ImportError):
    from ...dyn.sheet.range_selection_arguments import RangeSelectionArguments as RangeSelectionArguments
with suppress(ImportError):
    from ...dyn.sheet.range_selection_event import RangeSelectionEvent as RangeSelectionEvent
with suppress(ImportError):
    from ...dyn.sheet.recent_functions import RecentFunctions as RecentFunctions
with suppress(ImportError):
    from ...dyn.sheet.reference_flags import ReferenceFlags as ReferenceFlags
with suppress(ImportError):
    from ...dyn.sheet.reference_flags import ReferenceFlagsEnum as ReferenceFlagsEnum
with suppress(ImportError):
    from ...dyn.sheet.result_event import ResultEvent as ResultEvent
with suppress(ImportError):
    from ...dyn.sheet.scenario import Scenario as Scenario
with suppress(ImportError):
    from ...dyn.sheet.scenarios import Scenarios as Scenarios
with suppress(ImportError):
    from ...dyn.sheet.scenarios_enumeration import ScenariosEnumeration as ScenariosEnumeration
with suppress(ImportError):
    from ...dyn.sheet.shape import Shape as Shape
with suppress(ImportError):
    from ...dyn.sheet.sheet_cell import SheetCell as SheetCell
with suppress(ImportError):
    from ...dyn.sheet.sheet_cell_cursor import SheetCellCursor as SheetCellCursor
with suppress(ImportError):
    from ...dyn.sheet.sheet_cell_range import SheetCellRange as SheetCellRange
with suppress(ImportError):
    from ...dyn.sheet.sheet_cell_ranges import SheetCellRanges as SheetCellRanges
with suppress(ImportError):
    from ...dyn.sheet.sheet_cell_ranges_enumeration import SheetCellRangesEnumeration as SheetCellRangesEnumeration
with suppress(ImportError):
    from ...dyn.sheet.sheet_filter_descriptor import SheetFilterDescriptor as SheetFilterDescriptor
with suppress(ImportError):
    from ...dyn.sheet.sheet_link import SheetLink as SheetLink
with suppress(ImportError):
    from ...dyn.sheet.sheet_link_mode import SheetLinkMode as SheetLinkMode
with suppress(ImportError):
    from ...dyn.sheet.sheet_links import SheetLinks as SheetLinks
with suppress(ImportError):
    from ...dyn.sheet.sheet_links_enumeration import SheetLinksEnumeration as SheetLinksEnumeration
with suppress(ImportError):
    from ...dyn.sheet.sheet_ranges_query import SheetRangesQuery as SheetRangesQuery
with suppress(ImportError):
    from ...dyn.sheet.sheet_sort_descriptor import SheetSortDescriptor as SheetSortDescriptor
with suppress(ImportError):
    from ...dyn.sheet.sheet_sort_descriptor2 import SheetSortDescriptor2 as SheetSortDescriptor2
with suppress(ImportError):
    from ...dyn.sheet.single_reference import SingleReference as SingleReference
with suppress(ImportError):
    from ...dyn.sheet.solver import Solver as Solver
with suppress(ImportError):
    from ...dyn.sheet.solver_constraint import SolverConstraint as SolverConstraint
with suppress(ImportError):
    from ...dyn.sheet.solver_constraint_operator import SolverConstraintOperator as SolverConstraintOperator
with suppress(ImportError):
    from ...dyn.sheet.spreadsheet import Spreadsheet as Spreadsheet
with suppress(ImportError):
    from ...dyn.sheet.spreadsheet_document import SpreadsheetDocument as SpreadsheetDocument
with suppress(ImportError):
    from ...dyn.sheet.spreadsheet_document_settings import SpreadsheetDocumentSettings as SpreadsheetDocumentSettings
with suppress(ImportError):
    from ...dyn.sheet.spreadsheet_draw_page import SpreadsheetDrawPage as SpreadsheetDrawPage
with suppress(ImportError):
    from ...dyn.sheet.spreadsheet_view import SpreadsheetView as SpreadsheetView
with suppress(ImportError):
    from ...dyn.sheet.spreadsheet_view_objects_mode import SpreadsheetViewObjectsMode as SpreadsheetViewObjectsMode
with suppress(ImportError):
    from ...dyn.sheet.spreadsheet_view_objects_mode import SpreadsheetViewObjectsModeEnum as SpreadsheetViewObjectsModeEnum
with suppress(ImportError):
    from ...dyn.sheet.spreadsheet_view_pane import SpreadsheetViewPane as SpreadsheetViewPane
with suppress(ImportError):
    from ...dyn.sheet.spreadsheet_view_panes_enumeration import SpreadsheetViewPanesEnumeration as SpreadsheetViewPanesEnumeration
with suppress(ImportError):
    from ...dyn.sheet.spreadsheet_view_settings import SpreadsheetViewSettings as SpreadsheetViewSettings
with suppress(ImportError):
    from ...dyn.sheet.spreadsheets import Spreadsheets as Spreadsheets
with suppress(ImportError):
    from ...dyn.sheet.spreadsheets_enumeration import SpreadsheetsEnumeration as SpreadsheetsEnumeration
with suppress(ImportError):
    from ...dyn.sheet.status_bar_function import StatusBarFunction as StatusBarFunction
with suppress(ImportError):
    from ...dyn.sheet.status_bar_function import StatusBarFunctionEnum as StatusBarFunctionEnum
with suppress(ImportError):
    from ...dyn.sheet.sub_total_column import SubTotalColumn as SubTotalColumn
with suppress(ImportError):
    from ...dyn.sheet.sub_total_descriptor import SubTotalDescriptor as SubTotalDescriptor
with suppress(ImportError):
    from ...dyn.sheet.sub_total_field import SubTotalField as SubTotalField
with suppress(ImportError):
    from ...dyn.sheet.sub_total_fields_enumeration import SubTotalFieldsEnumeration as SubTotalFieldsEnumeration
with suppress(ImportError):
    from ...dyn.sheet.table_auto_format import TableAutoFormat as TableAutoFormat
with suppress(ImportError):
    from ...dyn.sheet.table_auto_format_enumeration import TableAutoFormatEnumeration as TableAutoFormatEnumeration
with suppress(ImportError):
    from ...dyn.sheet.table_auto_format_field import TableAutoFormatField as TableAutoFormatField
with suppress(ImportError):
    from ...dyn.sheet.table_auto_formats import TableAutoFormats as TableAutoFormats
with suppress(ImportError):
    from ...dyn.sheet.table_auto_formats_enumeration import TableAutoFormatsEnumeration as TableAutoFormatsEnumeration
with suppress(ImportError):
    from ...dyn.sheet.table_cell_style import TableCellStyle as TableCellStyle
with suppress(ImportError):
    from ...dyn.sheet.table_conditional_entry import TableConditionalEntry as TableConditionalEntry
with suppress(ImportError):
    from ...dyn.sheet.table_conditional_entry_enumeration import TableConditionalEntryEnumeration as TableConditionalEntryEnumeration
with suppress(ImportError):
    from ...dyn.sheet.table_conditional_format import TableConditionalFormat as TableConditionalFormat
with suppress(ImportError):
    from ...dyn.sheet.table_filter_field import TableFilterField as TableFilterField
with suppress(ImportError):
    from ...dyn.sheet.table_filter_field2 import TableFilterField2 as TableFilterField2
with suppress(ImportError):
    from ...dyn.sheet.table_filter_field3 import TableFilterField3 as TableFilterField3
with suppress(ImportError):
    from ...dyn.sheet.table_operation_mode import TableOperationMode as TableOperationMode
with suppress(ImportError):
    from ...dyn.sheet.table_page_break_data import TablePageBreakData as TablePageBreakData
with suppress(ImportError):
    from ...dyn.sheet.table_page_style import TablePageStyle as TablePageStyle
with suppress(ImportError):
    from ...dyn.sheet.table_validation import TableValidation as TableValidation
with suppress(ImportError):
    from ...dyn.sheet.table_validation_visibility import TableValidationVisibility as TableValidationVisibility
with suppress(ImportError):
    from ...dyn.sheet.table_validation_visibility import TableValidationVisibilityEnum as TableValidationVisibilityEnum
with suppress(ImportError):
    from ...dyn.sheet.unique_cell_format_ranges import UniqueCellFormatRanges as UniqueCellFormatRanges
with suppress(ImportError):
    from ...dyn.sheet.unique_cell_format_ranges_enumeration import UniqueCellFormatRangesEnumeration as UniqueCellFormatRangesEnumeration
with suppress(ImportError):
    from ...dyn.sheet.validation_alert_style import ValidationAlertStyle as ValidationAlertStyle
with suppress(ImportError):
    from ...dyn.sheet.validation_type import ValidationType as ValidationType
with suppress(ImportError):
    from ...dyn.sheet.volatile_result import VolatileResult as VolatileResult
with suppress(ImportError):
    from ...dyn.sheet.x_activation_broadcaster import XActivationBroadcaster as XActivationBroadcaster
with suppress(ImportError):
    from ...dyn.sheet.x_activation_event_listener import XActivationEventListener as XActivationEventListener
with suppress(ImportError):
    from ...dyn.sheet.x_add_in import XAddIn as XAddIn
with suppress(ImportError):
    from ...dyn.sheet.x_area_link import XAreaLink as XAreaLink
with suppress(ImportError):
    from ...dyn.sheet.x_area_links import XAreaLinks as XAreaLinks
with suppress(ImportError):
    from ...dyn.sheet.x_array_formula_range import XArrayFormulaRange as XArrayFormulaRange
with suppress(ImportError):
    from ...dyn.sheet.x_array_formula_tokens import XArrayFormulaTokens as XArrayFormulaTokens
with suppress(ImportError):
    from ...dyn.sheet.x_calculatable import XCalculatable as XCalculatable
with suppress(ImportError):
    from ...dyn.sheet.x_cell_addressable import XCellAddressable as XCellAddressable
with suppress(ImportError):
    from ...dyn.sheet.x_cell_format_ranges_supplier import XCellFormatRangesSupplier as XCellFormatRangesSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_cell_range_addressable import XCellRangeAddressable as XCellRangeAddressable
with suppress(ImportError):
    from ...dyn.sheet.x_cell_range_data import XCellRangeData as XCellRangeData
with suppress(ImportError):
    from ...dyn.sheet.x_cell_range_formula import XCellRangeFormula as XCellRangeFormula
with suppress(ImportError):
    from ...dyn.sheet.x_cell_range_movement import XCellRangeMovement as XCellRangeMovement
with suppress(ImportError):
    from ...dyn.sheet.x_cell_range_referrer import XCellRangeReferrer as XCellRangeReferrer
with suppress(ImportError):
    from ...dyn.sheet.x_cell_ranges_access import XCellRangesAccess as XCellRangesAccess
with suppress(ImportError):
    from ...dyn.sheet.x_cell_ranges_query import XCellRangesQuery as XCellRangesQuery
with suppress(ImportError):
    from ...dyn.sheet.x_cell_series import XCellSeries as XCellSeries
with suppress(ImportError):
    from ...dyn.sheet.x_color_scale_entry import XColorScaleEntry as XColorScaleEntry
with suppress(ImportError):
    from ...dyn.sheet.x_compatibility_names import XCompatibilityNames as XCompatibilityNames
with suppress(ImportError):
    from ...dyn.sheet.x_condition_entry import XConditionEntry as XConditionEntry
with suppress(ImportError):
    from ...dyn.sheet.x_conditional_format import XConditionalFormat as XConditionalFormat
with suppress(ImportError):
    from ...dyn.sheet.x_conditional_formats import XConditionalFormats as XConditionalFormats
with suppress(ImportError):
    from ...dyn.sheet.x_consolidatable import XConsolidatable as XConsolidatable
with suppress(ImportError):
    from ...dyn.sheet.x_consolidation_descriptor import XConsolidationDescriptor as XConsolidationDescriptor
with suppress(ImportError):
    from ...dyn.sheet.xdde_link import XDDELink as XDDELink
with suppress(ImportError):
    from ...dyn.sheet.xdde_link_results import XDDELinkResults as XDDELinkResults
with suppress(ImportError):
    from ...dyn.sheet.xdde_links import XDDELinks as XDDELinks
with suppress(ImportError):
    from ...dyn.sheet.x_data_bar_entry import XDataBarEntry as XDataBarEntry
with suppress(ImportError):
    from ...dyn.sheet.x_data_pilot_data_layout_field_supplier import XDataPilotDataLayoutFieldSupplier as XDataPilotDataLayoutFieldSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_data_pilot_descriptor import XDataPilotDescriptor as XDataPilotDescriptor
with suppress(ImportError):
    from ...dyn.sheet.x_data_pilot_field import XDataPilotField as XDataPilotField
with suppress(ImportError):
    from ...dyn.sheet.x_data_pilot_field_grouping import XDataPilotFieldGrouping as XDataPilotFieldGrouping
with suppress(ImportError):
    from ...dyn.sheet.x_data_pilot_member_results import XDataPilotMemberResults as XDataPilotMemberResults
with suppress(ImportError):
    from ...dyn.sheet.x_data_pilot_results import XDataPilotResults as XDataPilotResults
with suppress(ImportError):
    from ...dyn.sheet.x_data_pilot_table import XDataPilotTable as XDataPilotTable
with suppress(ImportError):
    from ...dyn.sheet.x_data_pilot_table2 import XDataPilotTable2 as XDataPilotTable2
with suppress(ImportError):
    from ...dyn.sheet.x_data_pilot_tables import XDataPilotTables as XDataPilotTables
with suppress(ImportError):
    from ...dyn.sheet.x_data_pilot_tables_supplier import XDataPilotTablesSupplier as XDataPilotTablesSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_database_range import XDatabaseRange as XDatabaseRange
with suppress(ImportError):
    from ...dyn.sheet.x_database_ranges import XDatabaseRanges as XDatabaseRanges
with suppress(ImportError):
    from ...dyn.sheet.x_dimensions_supplier import XDimensionsSupplier as XDimensionsSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_document_auditing import XDocumentAuditing as XDocumentAuditing
with suppress(ImportError):
    from ...dyn.sheet.x_drill_down_data_supplier import XDrillDownDataSupplier as XDrillDownDataSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_enhanced_mouse_click_broadcaster import XEnhancedMouseClickBroadcaster as XEnhancedMouseClickBroadcaster
with suppress(ImportError):
    from ...dyn.sheet.x_external_doc_link import XExternalDocLink as XExternalDocLink
with suppress(ImportError):
    from ...dyn.sheet.x_external_doc_links import XExternalDocLinks as XExternalDocLinks
with suppress(ImportError):
    from ...dyn.sheet.x_external_sheet_cache import XExternalSheetCache as XExternalSheetCache
with suppress(ImportError):
    from ...dyn.sheet.x_external_sheet_name import XExternalSheetName as XExternalSheetName
with suppress(ImportError):
    from ...dyn.sheet.x_fill_across_sheet import XFillAcrossSheet as XFillAcrossSheet
with suppress(ImportError):
    from ...dyn.sheet.x_filter_formula_parser import XFilterFormulaParser as XFilterFormulaParser
with suppress(ImportError):
    from ...dyn.sheet.x_formula_op_code_mapper import XFormulaOpCodeMapper as XFormulaOpCodeMapper
with suppress(ImportError):
    from ...dyn.sheet.x_formula_parser import XFormulaParser as XFormulaParser
with suppress(ImportError):
    from ...dyn.sheet.x_formula_query import XFormulaQuery as XFormulaQuery
with suppress(ImportError):
    from ...dyn.sheet.x_formula_tokens import XFormulaTokens as XFormulaTokens
with suppress(ImportError):
    from ...dyn.sheet.x_function_access import XFunctionAccess as XFunctionAccess
with suppress(ImportError):
    from ...dyn.sheet.x_function_descriptions import XFunctionDescriptions as XFunctionDescriptions
with suppress(ImportError):
    from ...dyn.sheet.x_global_sheet_settings import XGlobalSheetSettings as XGlobalSheetSettings
with suppress(ImportError):
    from ...dyn.sheet.x_goal_seek import XGoalSeek as XGoalSeek
with suppress(ImportError):
    from ...dyn.sheet.x_header_footer_content import XHeaderFooterContent as XHeaderFooterContent
with suppress(ImportError):
    from ...dyn.sheet.x_hierarchies_supplier import XHierarchiesSupplier as XHierarchiesSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_icon_set_entry import XIconSetEntry as XIconSetEntry
with suppress(ImportError):
    from ...dyn.sheet.x_label_range import XLabelRange as XLabelRange
with suppress(ImportError):
    from ...dyn.sheet.x_label_ranges import XLabelRanges as XLabelRanges
with suppress(ImportError):
    from ...dyn.sheet.x_levels_supplier import XLevelsSupplier as XLevelsSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_members_access import XMembersAccess as XMembersAccess
with suppress(ImportError):
    from ...dyn.sheet.x_members_supplier import XMembersSupplier as XMembersSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_multi_formula_tokens import XMultiFormulaTokens as XMultiFormulaTokens
with suppress(ImportError):
    from ...dyn.sheet.x_multiple_operation import XMultipleOperation as XMultipleOperation
with suppress(ImportError):
    from ...dyn.sheet.x_named_range import XNamedRange as XNamedRange
with suppress(ImportError):
    from ...dyn.sheet.x_named_ranges import XNamedRanges as XNamedRanges
with suppress(ImportError):
    from ...dyn.sheet.x_print_areas import XPrintAreas as XPrintAreas
with suppress(ImportError):
    from ...dyn.sheet.x_range_selection import XRangeSelection as XRangeSelection
with suppress(ImportError):
    from ...dyn.sheet.x_range_selection_change_listener import XRangeSelectionChangeListener as XRangeSelectionChangeListener
with suppress(ImportError):
    from ...dyn.sheet.x_range_selection_listener import XRangeSelectionListener as XRangeSelectionListener
with suppress(ImportError):
    from ...dyn.sheet.x_recent_functions import XRecentFunctions as XRecentFunctions
with suppress(ImportError):
    from ...dyn.sheet.x_result_listener import XResultListener as XResultListener
with suppress(ImportError):
    from ...dyn.sheet.x_scenario import XScenario as XScenario
with suppress(ImportError):
    from ...dyn.sheet.x_scenario_enhanced import XScenarioEnhanced as XScenarioEnhanced
with suppress(ImportError):
    from ...dyn.sheet.x_scenarios import XScenarios as XScenarios
with suppress(ImportError):
    from ...dyn.sheet.x_scenarios_supplier import XScenariosSupplier as XScenariosSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_selected_sheets_supplier import XSelectedSheetsSupplier as XSelectedSheetsSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_annotation import XSheetAnnotation as XSheetAnnotation
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_annotation_anchor import XSheetAnnotationAnchor as XSheetAnnotationAnchor
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_annotation_shape_supplier import XSheetAnnotationShapeSupplier as XSheetAnnotationShapeSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_annotations import XSheetAnnotations as XSheetAnnotations
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_annotations_supplier import XSheetAnnotationsSupplier as XSheetAnnotationsSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_auditing import XSheetAuditing as XSheetAuditing
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_cell_cursor import XSheetCellCursor as XSheetCellCursor
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_cell_range import XSheetCellRange as XSheetCellRange
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_cell_range_container import XSheetCellRangeContainer as XSheetCellRangeContainer
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_cell_ranges import XSheetCellRanges as XSheetCellRanges
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_condition import XSheetCondition as XSheetCondition
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_condition2 import XSheetCondition2 as XSheetCondition2
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_conditional_entries import XSheetConditionalEntries as XSheetConditionalEntries
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_conditional_entry import XSheetConditionalEntry as XSheetConditionalEntry
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_filter_descriptor import XSheetFilterDescriptor as XSheetFilterDescriptor
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_filter_descriptor2 import XSheetFilterDescriptor2 as XSheetFilterDescriptor2
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_filter_descriptor3 import XSheetFilterDescriptor3 as XSheetFilterDescriptor3
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_filterable import XSheetFilterable as XSheetFilterable
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_filterable_ex import XSheetFilterableEx as XSheetFilterableEx
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_linkable import XSheetLinkable as XSheetLinkable
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_operation import XSheetOperation as XSheetOperation
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_outline import XSheetOutline as XSheetOutline
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_page_break import XSheetPageBreak as XSheetPageBreak
with suppress(ImportError):
    from ...dyn.sheet.x_sheet_pastable import XSheetPastable as XSheetPastable
with suppress(ImportError):
    from ...dyn.sheet.x_solver import XSolver as XSolver
with suppress(ImportError):
    from ...dyn.sheet.x_solver_description import XSolverDescription as XSolverDescription
with suppress(ImportError):
    from ...dyn.sheet.x_spreadsheet import XSpreadsheet as XSpreadsheet
with suppress(ImportError):
    from ...dyn.sheet.x_spreadsheet_document import XSpreadsheetDocument as XSpreadsheetDocument
with suppress(ImportError):
    from ...dyn.sheet.x_spreadsheet_view import XSpreadsheetView as XSpreadsheetView
with suppress(ImportError):
    from ...dyn.sheet.x_spreadsheets import XSpreadsheets as XSpreadsheets
with suppress(ImportError):
    from ...dyn.sheet.x_spreadsheets2 import XSpreadsheets2 as XSpreadsheets2
with suppress(ImportError):
    from ...dyn.sheet.x_sub_total_calculatable import XSubTotalCalculatable as XSubTotalCalculatable
with suppress(ImportError):
    from ...dyn.sheet.x_sub_total_descriptor import XSubTotalDescriptor as XSubTotalDescriptor
with suppress(ImportError):
    from ...dyn.sheet.x_sub_total_field import XSubTotalField as XSubTotalField
with suppress(ImportError):
    from ...dyn.sheet.x_unique_cell_format_ranges_supplier import XUniqueCellFormatRangesSupplier as XUniqueCellFormatRangesSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_unnamed_database_ranges import XUnnamedDatabaseRanges as XUnnamedDatabaseRanges
with suppress(ImportError):
    from ...dyn.sheet.x_used_area_cursor import XUsedAreaCursor as XUsedAreaCursor
with suppress(ImportError):
    from ...dyn.sheet.x_view_freezable import XViewFreezable as XViewFreezable
with suppress(ImportError):
    from ...dyn.sheet.x_view_pane import XViewPane as XViewPane
with suppress(ImportError):
    from ...dyn.sheet.x_view_panes_supplier import XViewPanesSupplier as XViewPanesSupplier
with suppress(ImportError):
    from ...dyn.sheet.x_view_splitable import XViewSplitable as XViewSplitable
with suppress(ImportError):
    from ...dyn.sheet.x_volatile_result import XVolatileResult as XVolatileResult



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed


class EmbedMapUnits(object):
    """
    Const Class

    contains list of possible map modes supported by embedded object.

    See Also:
        `API EmbedMapUnits <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1EmbedMapUnits.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.EmbedMapUnits'
    __ooo_type_name__: str = 'const'

    ONE_100TH_MM = 0
    """
    In this type of map mode one logical point is equal to one-hundredth of millimeter.
    """
    ONE_10TH_MM = 1
    """
    In this type of map mode one logical point is equal to one-tenth of millimeter.
    """
    ONE_MM = 2
    """
    In this type of map mode one logical point is equal to one millimeter.
    """
    ONE_CM = 3
    """
    In this type of map mode one logical point is equal to one centimeter.
    """
    ONE_1000TH_INCH = 4
    """
    In this type of map mode one logical point is equal to one-thousandth of inch.
    """
    ONE_100TH_INCH = 5
    """
    In this type of map mode one logical point is equal to one-hundredth of inch.
    """
    ONE_10TH_INCH = 6
    """
    In this type of map mode one logical point is equal to one-tenth of inch.
    """
    ONE_INCH = 7
    """
    In this type of map mode one logical point is equal to one inch.
    """
    POINT = 8
    """
    In this type of map mode one logical point is equal to one typographical point.
    """
    TWIP = 9
    """
    In this type of map mode one logical point is equal to one twentieth of typographical point.
    """
    PIXEL = 10
    """
    In this type of map mode one logical point is equal to one pixel.
    """

__all__ = ['EmbedMapUnits']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto


class DigestID(object):
    """
    Const Class

    The constant set contains identifiers of supported digest-creation algorithms.
    
    **since**
    
        OOo 3.4

    See Also:
        `API DigestID <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1DigestID.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.DigestID'
    __ooo_type_name__: str = 'const'

    SHA1 = 1
    """
    identifier of SHA-1 algorithm
    """
    SHA256 = 2
    """
    identifier of SHA-256 algorithm
    """
    SHA1_1K = 3
    """
    identifier of SHA-1 algorithm that is applied to the first kilobyte of data.
    """
    SHA256_1K = 4
    """
    identifier of SHA-256 algorithm that is applied to the first kilobyte of data.
    """
    SHA512 = 5
    """
    identifier of SHA-512 algorithm
    
    **since**
    
        LibreOffice 6.0
    """
    SHA512_1K = 6
    """
    identifier of SHA-512 algorithm that is applied to the first kilobyte of data.
    
    **since**
    
        LibreOffice 6.0
    """

__all__ = ['DigestID']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
import uno
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class VerbAttributes(metaclass=UnoConstMeta, type_name="com.sun.star.embed.VerbAttributes", name_space="com.sun.star.embed"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.embed.VerbAttributes``"""
        pass

    class VerbAttributesEnum(IntFlag, metaclass=ConstEnumMeta, type_name="com.sun.star.embed.VerbAttributes", name_space="com.sun.star.embed"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.embed.VerbAttributes`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.embed import VerbAttributes as VerbAttributes
    else:
        # keep document generators happy
        from ...lo.embed.verb_attributes import VerbAttributes as VerbAttributes

    class VerbAttributesEnum(IntFlag):
        """
        Enum of Const Class VerbAttributes

        The constant set specifies possible attributes of a verb.
        """
        MS_VERBATTR_NEVERDIRTIES = VerbAttributes.MS_VERBATTR_NEVERDIRTIES
        """
        Execution of the verb with this attribute must not modify the object.
        """
        MS_VERBATTR_ONCONTAINERMENU = VerbAttributes.MS_VERBATTR_ONCONTAINERMENU
        """
        indicates that the verb should appear in the object's menu.
        """

__all__ = ['VerbAttributes', 'VerbAttributesEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XRestoreListener(XEventListener_c7230c4a):
    """
    receives notifications about data being restored.
    
    Such a notification is typically sent when the user cancels updating the current record of a database form without saving the data. After restoring, the user operates on the original data.
    
    Please do not use anymore, this interface is deprecated, and superseded by functionality from the com.sun.star.form.component.DataForm and com.sun.star.sdb.RowSet services
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XRestoreListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XRestoreListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.XRestoreListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.XRestoreListener'

    @abstractmethod
    def restored(self, aEvent: EventObject_a3d70b03) -> None:
        """
        is invoked when a modified record has been restored
        """
        ...

__all__ = ['XRestoreListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_chart_data_change_event_listener import XChartDataChangeEventListener as XChartDataChangeEventListener_bb19126c

class XChartData(XInterface_8f010a43):
    """
    manages the data of the chart.

    See Also:
        `API XChartData <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart_1_1XChartData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.XChartData'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart.XChartData'

    @abstractmethod
    def addChartDataChangeEventListener(self, aListener: XChartDataChangeEventListener_bb19126c) -> None:
        """
        allows a component supporting the XChartDataChangeEventListener interface to register as listener.
        
        The component will be notified with a ChartDataChangeEvent every time the chart's data changes.
        """
        ...
    @abstractmethod
    def getNotANumber(self) -> float:
        """
        In IEEE arithmetic format it is one of the NaN values, so there are no conflicts with existing numeric values.
        """
        ...
    @abstractmethod
    def isNotANumber(self, nNumber: float) -> bool:
        """
        checks whether the value given is equal to the indicator value for a missing value.
        
        In IEEE arithmetic format it is one of the NaN values, so there are no conflicts with existing numeric values.
        
        Always use this method to check, if a value is not a number. If you compare the value returned by XChartData.getNotANumber() to another double value using the = operator, you may not get the desired result!
        """
        ...
    @abstractmethod
    def removeChartDataChangeEventListener(self, aListener: XChartDataChangeEventListener_bb19126c) -> None:
        """
        removes a previously registered listener.
        """
        ...

__all__ = ['XChartData']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class NormalsKind(Enum):
    """
    Enum Class


    See Also:
        `API NormalsKind <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a2f040e92a1488875fb14c6ecc377630b>`_
    """
    __ooo_ns__: str = "com.sun.star.drawing"
    __ooo_full_ns__: str = "com.sun.star.drawing.NormalsKind"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.drawing.NormalsKind"

    FLAT = "FLAT"
    """
    forces one normal per flat part.
    
    With FLAT shading, the faces of the object are rendered in a solid color.
    """
    SPECIFIC = "SPECIFIC"
    """
    does not produce standard normals, but leaves the object-specific ones untouched.
    """
    SPHERE = "SPHERE"
    """
    forces normals to think that the object is a sphere.
    
    This value forces projection to wrapping in X and/or Y.
    """

__all__ = ["NormalsKind"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.datatransfer.data_flavor import DataFlavor as DataFlavor
with suppress(ImportError):
    from ...dyn.datatransfer.data_format_translator import DataFormatTranslator as DataFormatTranslator
with suppress(ImportError):
    from ...dyn.datatransfer.mime_content_type_factory import MimeContentTypeFactory as MimeContentTypeFactory
with suppress(ImportError):
    from ...dyn.datatransfer.unsupported_flavor_exception import UnsupportedFlavorException as UnsupportedFlavorException
with suppress(ImportError):
    from ...dyn.datatransfer.x_data_format_translator import XDataFormatTranslator as XDataFormatTranslator
with suppress(ImportError):
    from ...dyn.datatransfer.x_mime_content_type import XMimeContentType as XMimeContentType
with suppress(ImportError):
    from ...dyn.datatransfer.x_mime_content_type_factory import XMimeContentTypeFactory as XMimeContentTypeFactory
with suppress(ImportError):
    from ...dyn.datatransfer.x_system_transferable import XSystemTransferable as XSystemTransferable
with suppress(ImportError):
    from ...dyn.datatransfer.x_transfer_data_access import XTransferDataAccess as XTransferDataAccess
with suppress(ImportError):
    from ...dyn.datatransfer.x_transferable import XTransferable as XTransferable
with suppress(ImportError):
    from ...dyn.datatransfer.x_transferable2 import XTransferable2 as XTransferable2
with suppress(ImportError):
    from ...dyn.datatransfer.x_transferable_ex import XTransferableEx as XTransferableEx
with suppress(ImportError):
    from ...dyn.datatransfer.x_transferable_source import XTransferableSource as XTransferableSource
with suppress(ImportError):
    from ...dyn.datatransfer.x_transferable_supplier import XTransferableSupplier as XTransferableSupplier
with suppress(ImportError):
    from ...dyn.datatransfer.x_transferable_text_supplier import XTransferableTextSupplier as XTransferableTextSupplier



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.style


class NumberingType(object):
    """
    Const Class

    These constants are used to specify which numbering style is used.
    
    **since**
    
        LibreOffice 7.0

    See Also:
        `API NumberingType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1style_1_1NumberingType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.style'
    __ooo_full_ns__: str = 'com.sun.star.style.NumberingType'
    __ooo_type_name__: str = 'const'

    CHARS_UPPER_LETTER = 0
    """
    Numbering is put in upper case letters as \"A, B, C, D, ...\".
    """
    CHARS_LOWER_LETTER = 1
    """
    Numbering is in lower case letters as \"a, b, c, e,...\".
    """
    ROMAN_UPPER = 2
    """
    Numbering is in Roman numbers with upper case letters as \"I, II, III, IV, ...\".
    """
    ROMAN_LOWER = 3
    """
    Numbering is in Roman numbers with lower case letters as \"i, ii, iii, iv, ...\".
    """
    ARABIC = 4
    """
    Numbering is in Arabic numbers as \"1, 2, 3, 4, ...\".
    """
    NUMBER_NONE = 5
    """
    Numbering is invisible.
    """
    CHAR_SPECIAL = 6
    """
    Use a character from a specified font.
    """
    PAGE_DESCRIPTOR = 7
    """
    Numbering is specified in the page style.
    """
    BITMAP = 8
    """
    Numbering is displayed as a bitmap graphic.
    """
    CHARS_UPPER_LETTER_N = 9
    """
    Numbering is put in upper case letters as \"A, B, ..., Y, Z, AA, BB, CC, ...
    
    AAA, ...\".
    """
    CHARS_LOWER_LETTER_N = 10
    """
    Numbering is put in lower case letters as \"a, b, ..., y, z, aa, bb, cc, ...
    
    aaa, ...\".
    """
    TRANSLITERATION = 11
    """
    A transliteration module will be used to produce numbers in Chinese, Japanese, etc.
    """
    NATIVE_NUMBERING = 12
    """
    The NativeNumberSupplier service will be called to produce numbers in native languages.
    """
    FULLWIDTH_ARABIC = 13
    """
    Numbering for fullwidth Arabic number.
    """
    CIRCLE_NUMBER = 14
    """
    Bullet for Circle Number.
    """
    NUMBER_LOWER_ZH = 15
    """
    Numbering for Chinese lower case number as \"&#19968;,&#20108;,&#19977;...\".
    """
    NUMBER_UPPER_ZH = 16
    """
    Numbering for Chinese upper case number.
    """
    NUMBER_UPPER_ZH_TW = 17
    """
    Numbering for Traditional Chinese upper case number.
    """
    TIAN_GAN_ZH = 18
    """
    Bullet for Chinese Tian Gan as \"&#30002;,&#20057;,&#19993;...\".
    """
    DI_ZI_ZH = 19
    """
    Bullet for Chinese Di Zi as \"&#23376;,&#19985;,&#23493;...\".
    """
    NUMBER_TRADITIONAL_JA = 20
    """
    Numbering for Japanese traditional number.
    """
    AIU_FULLWIDTH_JA = 21
    """
    Bullet for Japanese AIU fullwidth.
    """
    AIU_HALFWIDTH_JA = 22
    """
    Bullet for Japanese AIU halfwidth.
    """
    IROHA_FULLWIDTH_JA = 23
    """
    Bullet for Japanese IROHA fullwidth.
    """
    IROHA_HALFWIDTH_JA = 24
    """
    Bullet for Japanese IROHA halfwidth.
    """
    NUMBER_UPPER_KO = 25
    """
    Numbering for Korean upper case number as \"&#22777;,&#36019;,&#21443;...\".
    """
    NUMBER_HANGUL_KO = 26
    """
    Numbering for Korean Hangul number as \"&#51068;,&#51060;,&#49340;...\".
    """
    HANGUL_JAMO_KO = 27
    """
    Bullet for Korean Hangul Jamo as \"&#12593;,&#12596;,&#12599;...\".
    """
    HANGUL_SYLLABLE_KO = 28
    """
    Bullet for Korean Hangul Syllable as \"&#44032;,&#45208;,&#45796;...\".
    """
    HANGUL_CIRCLED_JAMO_KO = 29
    """
    Bullet for Korean Hangul Circled Jamo as \"&#12896;,&#12897;,&#12898;...\".
    """
    HANGUL_CIRCLED_SYLLABLE_KO = 30
    """
    Bullet for Korean Hangul Circled Syllable as \"&#12910;,&#12911;,&#12912;...\".
    """
    CHARS_ARABIC = 31
    """
    Numbering in Arabic alphabet letters as \"&#1571;,&#1576;,&#1578;...\".
    
    **since**
    
        OOo 1.1.2
    """
    CHARS_THAI = 32
    """
    Numbering in Thai alphabet letters.
    
    **since**
    
        OOo 1.1.2
    """
    CHARS_HEBREW = 33
    """
    Numbering in Hebrew alphabet letters.
    
    **since**
    
        OOo 2.0
    """
    CHARS_NEPALI = 34
    """
    Numbering in Nepali alphabet letters.
    
    **since**
    
        OOo 2.0.1
    """
    CHARS_KHMER = 35
    """
    Numbering in Khmer alphabet letters.
    
    **since**
    
        OOo 2.0.1
    """
    CHARS_LAO = 36
    """
    Numbering in Lao alphabet letters.
    
    **since**
    
        OOo 2.0.1
    """
    CHARS_TIBETAN = 37
    """
    Numbering in Tibetan/Dzongkha alphabet letters.
    
    **since**
    
        OOo 2.0.3
    """
    CHARS_CYRILLIC_UPPER_LETTER_BG = 38
    """
    Numbering in Cyrillic alphabet upper case letters as \"&#1040;, &#1041;,  &#1042;, &#1043;, ..., &#1070;, &#1071;, &#1040;&#1074;, &#1040;&#1072;, &#1040;&#1074;, ... &#1040;&#1072;&#1072;, &#1040;&#1072;&#1073;\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_LOWER_LETTER_BG = 39
    """
    Numbering in Cyrillic alphabet lower case letters as \"&#1072;, &#1073;, &#1074;, &#1075;, ..., &#1102;, &#1103;, &#1072; &#1072;,  &#1072;&#1073;, &#1072;&#1074;, ...  &#1072; &#1072; &#1072;,  &#1072; &#1072;&#1073;\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_UPPER_LETTER_N_BG = 40
    """
    Numbering in Cyrillic alphabet upper case letters as \"&#1040;, &#1041;, ..., &#1070;, &#1071;, &#1040;&#1072;, &#1041;&#1073;, &#1042;&#1074;, ... &#1040;&#1072;&#1072;, ...\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_LOWER_LETTER_N_BG = 41
    """
    Numbering in Cyrillic alphabet upper case letters as \"&#1072;, &#1073;, ..., &#1102;, &#1103;, &#1072;&#1072;, &#1073;&#1073;, &#1074;&#1074;, ... &#1072;&#1072;&#1072;, ...\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_UPPER_LETTER_RU = 42
    """
    Numbering in Russian Cyrillic alphabet upper case letters as \"&#1040;, &#1041;, &#1042;, &#1043;, ..., &#1070;, &#1071;, &#1040;&#1072;, &#1040;&#1073;, &#1040;&#1074;, ... &#1040;&#1072;&#1072;, &#1040;&#1072;&#1073;\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_LOWER_LETTER_RU = 43
    """
    Numbering in Russian Cyrillic alphabet lower case letters as \"&#1072;, &#1073;, &#1074;, &#1075;, ..., &#1102;, &#1103;, &#1072;&#1072;, &#1072;&#1073;, &#1072;&#1074;, ... &#1072;&#1072;&#1072;, &#1072;&#1072;&#1073;\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_UPPER_LETTER_N_RU = 44
    """
    Numbering in Russian Cyrillic alphabet upper case letters as \"&#1040;, &#1041;, ..., &#1070;, &#1071;, &#1040;&#1072;, &#1041;&#1073;, &#1042;&#1074;, ... &#1040;&#1072;&#1072;, ...\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_LOWER_LETTER_N_RU = 45
    """
    Numbering in Russian Cyrillic alphabet upper case letters as \"&#1072;, &#1073;, ..., &#1102;, &#1103;, &#1072;&#1072;, &#1073;&#1073;, &#1074;&#1074;, ... &#1072;&#1072;&#1072;, ...\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_PERSIAN = 46
    """
    Numbering in Persian alphabet letters (aa, be, pe, te, ...)
    
    **since**
    
        OOo 2.4
    """
    CHARS_MYANMAR = 47
    """
    Numbering in Myanmar alphabet letters.
    
    **since**
    
        OOo 3.1
    """
    CHARS_CYRILLIC_UPPER_LETTER_SR = 48
    """
    Numbering in Serbian Cyrillic alphabet upper case letters.
    
    **since**
    
        OOo 3.1
    """
    CHARS_CYRILLIC_LOWER_LETTER_SR = 49
    """
    Numbering in Russian Serbian alphabet lower case letters.
    
    **since**
    
        OOo 3.1
    """
    CHARS_CYRILLIC_UPPER_LETTER_N_SR = 50
    """
    Numbering in Serbian Cyrillic alphabet upper case letters.
    
    **since**
    
        OOo 3.1
    """
    CHARS_CYRILLIC_LOWER_LETTER_N_SR = 51
    """
    Numbering in Serbian Cyrillic alphabet upper case letters.
    
    **since**
    
        OOo 3.1
    """
    CHARS_GREEK_UPPER_LETTER = 52
    """
    Numbering in Greek alphabet upper case letters.
    
    **since**
    
        LibreOffice 3.3
    """
    CHARS_GREEK_LOWER_LETTER = 53
    """
    Numbering in Greek alphabet lower case letters.
    
    **since**
    
        LibreOffice 3.3
    """
    CHARS_ARABIC_ABJAD = 54
    """
    Numbering in Arabic alphabet using abjad sequence.
    
    **since**
    
        LibreOffice 3.5
    """
    CHARS_PERSIAN_WORD = 55
    """
    Numbering in Persian words.
    
    **since**
    
        LibreOffice 3.5
    """
    NUMBER_HEBREW = 56
    """
    Numbering in Hebrew numerals.
    
    **since**
    
        LibreOffice 5.4
    """
    NUMBER_ARABIC_INDIC = 57
    """
    Numbering in Arabic-Indic numerals.
    
    **since**
    
        LibreOffice 6.1
    """
    NUMBER_EAST_ARABIC_INDIC = 58
    """
    Numbering in East Arabic-Indic numerals.
    
    **since**
    
        LibreOffice 6.1
    """
    NUMBER_INDIC_DEVANAGARI = 59
    """
    Numbering in Indic Devanagari numerals.
    
    **since**
    
        LibreOffice 6.1
    """
    TEXT_NUMBER = 60
    """
    Numbering in ordinal numbers of the language of the text node for example, 1st, 2nd, 3rd...
    
    in English
    
    **since**
    
        LibreOffice 6.1
    """
    TEXT_CARDINAL = 61
    """
    Numbering in cardinal numbers of the language of the text node for example, One, Two, Three...
    
    in English
    
    **since**
    
        LibreOffice 6.1
    """
    TEXT_ORDINAL = 62
    """
    Numbering in ordinal numbers of the language of the text node for example, First, Second, Third...
    
    in English
    
    **since**
    
        LibreOffice 6.1
    """
    SYMBOL_CHICAGO = 63
    """
    Footnoting symbols according the University of Chicago style: *, &#2020;, &#2021;, &#00a7;, **, &#2020;&#2020; etc.
    
    **since**
    
        LibreOffice 6.4
    """
    ARABIC_ZERO = 64
    """
    Numbering is in Arabic numbers, padded with zero to have a length of at least two, as \"01,02, ..., 10, 11, ...\".
    
    **since**
    
        LibreOffice 7.0
    """
    ARABIC_ZERO3 = 65
    """
    Numbering is in Arabic numbers, padded with zero to have a length of at least three, as \"001, 002, ..., 100, 101, ...\".
    
    **since**
    
        LibreOffice 7.0
    """
    ARABIC_ZERO4 = 66
    """
    Numbering is in Arabic numbers, padded with zero to have a length of at least four, as \"0001, 0002, ..., 1000, 1001, ...\".
    
    **since**
    
        LibreOffice 7.0
    """
    ARABIC_ZERO5 = 67
    """
    Numbering is in Arabic numbers, padded with zero to have a length of at least five, as \"00001, 00002, ..., 10000, 10001, ...\".
    
    **since**
    
        LibreOffice 7.0
    """
    SZEKELY_ROVAS = 68
    """
    Numbering is in Szekely rovas (Old Hungarian) numerals.
    
    **since**
    
        LibreOffice 7.1
    """
    NUMBER_DIGITAL_KO = 69
    """
    Numbering is in Korean Digital number as \"ì¼,ì´,ì¼,...,ì¼ì,ì¼ìì, ...\".
    
    **since**
    
        LibreOffice 7.3
    """
    NUMBER_DIGITAL2_KO = 70
    """
    Numbering is in Korean Digital Number, reserved \"koreanDigital2\", as \"ä¸,äº,ä¸,...,ä¸ï¦²,ä¸ï¦²ï¦², ...\".
    
    **since**
    
        LibreOffice 7.3
    """
    NUMBER_LEGAL_KO = 71
    """
    Numbering is in Korean Legal Number, reserved \"koreanLegal\", as \"íë,ë,ì
    ,...\".
    
    **since**
    
        LibreOffice 7.3
    """

__all__ = ['NumberingType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_canvas import XCanvas as XCanvas_b19b0b7a
if typing.TYPE_CHECKING:
    from ..geometry.real_size2_d import RealSize2D as RealSize2D_ca1a0c09
    from .x_animated_sprite import XAnimatedSprite as XAnimatedSprite_1bc70eb8
    from .x_animation import XAnimation as XAnimation_d6910cbe
    from .x_bitmap import XBitmap as XBitmap_b1b70b7b
    from .x_custom_sprite import XCustomSprite as XCustomSprite_3a0e10
    from .x_sprite import XSprite as XSprite_b2470b95

class XSpriteCanvas(XCanvas_b19b0b7a):
    """
    Specialization of a XCanvas, where moving, animated objects (called sprites) are supported.

    See Also:
        `API XSpriteCanvas <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XSpriteCanvas.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XSpriteCanvas'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XSpriteCanvas'

    @abstractmethod
    def createClonedSprite(self, original: XSprite_b2470b95) -> XSprite_b2470b95:
        """
        Create a cloned version of an already existing sprite object.
        
        The cloned sprite always shows the same content as its original, but of course the sprite position, visibility, alpha etc. can be modified independently.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def createCustomSprite(self, spriteSize: RealSize2D_ca1a0c09) -> XCustomSprite_3a0e10:
        """
        Create a custom, user-handles-it-all sprite object.
        
        A sprite is a back-buffered object with its own, independent animation.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def createSpriteFromAnimation(self, animation: XAnimation_d6910cbe) -> XAnimatedSprite_1bc70eb8:
        """
        Create a sprite object from the specified animation sequence.
        
        A sprite is a back-buffered object with its own, independent animation.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def createSpriteFromBitmaps(self, animationBitmaps: typing.Tuple[XBitmap_b1b70b7b, ...], interpolationMode: int) -> XAnimatedSprite_1bc70eb8:
        """
        Create a sprite object from the specified animation sequence.
        
        A sprite is a back-buffered object with its own, independent animation.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...
    @abstractmethod
    def updateScreen(self, bUpdateAll: bool) -> bool:
        """
        Tells the sprite canvas to now update the screen representation.
        
        Required to display rendered changes to the canvas, and updates to stopped animations and XCustomSprites in general. This method will return only after the screen update is done, or earlier if an error happened.
        
        If double buffering is enabled via XBufferController, no explicit call of updateScreen() is necessary, since the XBufferController methods will automatically notify all associated XSpriteCanvas instances.
        """
        ...

__all__ = ['XSpriteCanvas']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..beans.property import Property as Property_8f4e0a76


class PropertyCommandArgument(object):
    """
    Struct Class

    The argument for the \"addProperty\" command.
    
    **since**
    
        Apache OpenOffice 4.0, LibreOffice 4.2

    See Also:
        `API PropertyCommandArgument <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1PropertyCommandArgument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.PropertyCommandArgument'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.PropertyCommandArgument'
    """Literal Constant ``com.sun.star.ucb.PropertyCommandArgument``"""

    def __init__(self, Property: typing.Optional[Property_8f4e0a76] = UNO_NONE, DefaultValue: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Property (Property, optional): Property value.
            DefaultValue (object, optional): DefaultValue value.
        """
        super().__init__()

        if isinstance(Property, PropertyCommandArgument):
            oth: PropertyCommandArgument = Property
            self.Property = oth.Property
            self.DefaultValue = oth.DefaultValue
            return

        kargs = {
            "Property": Property,
            "DefaultValue": DefaultValue,
        }
        if kargs["Property"] is UNO_NONE:
            kargs["Property"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._property = kwargs["Property"]
        self._default_value = kwargs["DefaultValue"]


    @property
    def Property(self) -> Property_8f4e0a76:
        """
        The property that the command has to add.
        """
        return self._property

    @Property.setter
    def Property(self, value: Property_8f4e0a76) -> None:
        self._property = value

    @property
    def DefaultValue(self) -> object:
        """
        The default value of the property.
        """
        return self._default_value

    @DefaultValue.setter
    def DefaultValue(self, value: object) -> None:
        self._default_value = value


__all__ = ['PropertyCommandArgument']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report


class GroupOn(object):
    """
    Const Class

    Specifies how to group data.

    See Also:
        `API GroupOn <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1report_1_1GroupOn.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report'
    __ooo_full_ns__: str = 'com.sun.star.report.GroupOn'
    __ooo_type_name__: str = 'const'

    DEFAULT = 0
    """
    The same value in the column value or expression.
    """
    PREFIX_CHARACTERS = 1
    """
    The same first nth of characters in the column value or expression.
    """
    YEAR = 2
    """
    Dates in the same calendar year.
    """
    QUARTAL = 3
    """
    Dates in the same calendar quarter.
    """
    MONTH = 4
    """
    Dates in the same month.
    """
    WEEK = 5
    """
    Dates in the same week.
    """
    DAY = 6
    """
    Dates on the same date.
    """
    HOUR = 7
    """
    Times in the same hour.
    """
    MINUTE = 8
    """
    Times in the same minute.
    """
    INTERVAL = 9
    """
    Values within an interval you specify.
    """

__all__ = ['GroupOn']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.table
from __future__ import annotations
from abc import abstractmethod
from .x_cell import XCell as XCell_70d408e8

class XCell2(XCell_70d408e8):
    """
    extends XCell methods to access the contents of a cell in a table.

    See Also:
        `API XCell2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1table_1_1XCell2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.XCell2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.table.XCell2'

    @abstractmethod
    def setFormulaResult(self, nValue: float) -> None:
        """
        sets a formula result into the cell.
        
        When assigned, the formula cell's result will be set to this value and will not be calculated - unless a HardRecalc is executed.
        """
        ...
    @abstractmethod
    def setFormulaString(self, aFormula: str) -> None:
        """
        sets a formula string into the cell.
        
        When assigned, the formula is set into the string. But is not compiled, tokenized or calculated. Its useful when loading a document and setFormulaResult() is used. Otherwise it is compiled on trying to fetch a result value.
        """
        ...

__all__ = ['XCell2']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbcx
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class Descriptor(XPropertySet_bc180bfa):
    """
    Service Class

    is used to create a new object within a database.
    
    A descriptor is commonly created by the container of a specific object, such as, tables or views. After the creation of the descriptor the properties have to be filled. Afterwards, you append the descriptor to the container and the container creates a new object based on the information of the descriptor. The descriptor can be used to create several objects.
    
    A descriptor contains at least the information of the name of an object.

    See Also:
        `API Descriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbcx_1_1Descriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbcx'
    __ooo_full_ns__: str = 'com.sun.star.sdbcx.Descriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Name(self) -> str:
        """
        is the name for the object to create.
        """
        ...


__all__ = ['Descriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.component
from __future__ import annotations
from abc import abstractproperty
from ...awt.uno_control_combo_box_model import UnoControlComboBoxModel as UnoControlComboBoxModel_39030f71
from ..form_control_model import FormControlModel as FormControlModel_e2990d22
from ..x_reset import XReset as XReset_71670917

class ComboBox(UnoControlComboBoxModel_39030f71, FormControlModel_e2990d22, XReset_71670917):
    """
    Service Class

    specifies a component which allows the input of text or selection of text from a list of text values.

    See Also:
        `API ComboBox <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1ComboBox.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.component'
    __ooo_full_ns__: str = 'com.sun.star.form.component.ComboBox'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DefaultText(self) -> str:
        """
        contains a default value for the control.
        
        This value is used when the control is initially displayed, and for resetting it.
        """
        ...


__all__ = ['ComboBox']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
from abc import abstractmethod
from .x_input_stream import XInputStream as XInputStream_98d40ab4

class XDataInputStream(XInputStream_98d40ab4):
    """
    makes it possible to read machine-independent simple data types from a stream.

    See Also:
        `API XDataInputStream <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XDataInputStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XDataInputStream'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XDataInputStream'

    @abstractmethod
    def readBoolean(self) -> int:
        """
        reads in a boolean.
        
        It is an 8-bit value. 0 means FALSE; all other values mean TRUE.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readByte(self) -> int:
        """
        reads an 8-bit byte.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readChar(self) -> str:
        """
        reads a 16-bit unicode character.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readDouble(self) -> float:
        """
        reads a 64-bit IEEE double.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readFloat(self) -> float:
        """
        reads a 32-bit IEEE float.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readHyper(self) -> int:
        """
        reads a 64-bit big endian integer.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readLong(self) -> int:
        """
        reads a 32-bit big endian integer.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readShort(self) -> int:
        """
        reads a 16-bit big endian integer.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readUTF(self) -> str:
        """
        reads a string of UTF encoded characters.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...

__all__ = ['XDataInputStream']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ....dyn.packages.zip.x_zip_file_access import XZipFileAccess as XZipFileAccess
with suppress(ImportError):
    from ....dyn.packages.zip.x_zip_file_access2 import XZipFileAccess2 as XZipFileAccess2
with suppress(ImportError):
    from ....dyn.packages.zip.zip_constants import ZipConstants as ZipConstants
with suppress(ImportError):
    from ....dyn.packages.zip.zip_constants import ZipConstantsEnum as ZipConstantsEnum
with suppress(ImportError):
    from ....dyn.packages.zip.zip_entry import ZipEntry as ZipEntry
with suppress(ImportError):
    from ....dyn.packages.zip.zip_exception import ZipException as ZipException
with suppress(ImportError):
    from ....dyn.packages.zip.zip_file_access import ZipFileAccess as ZipFileAccess
with suppress(ImportError):
    from ....dyn.packages.zip.zip_io_exception import ZipIOException as ZipIOException



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .mouse_event import MouseEvent as MouseEvent_8f430a5f

class XMouseListener(XEventListener_c7230c4a):
    """
    makes it possible to receive events from the mouse in a certain window.
    
    Use the following interfaces which allow to receive (and consume) mouse events even on windows which are not at the top:

    See Also:
        `API XMouseListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XMouseListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XMouseListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XMouseListener'

    @abstractmethod
    def mouseEntered(self, e: MouseEvent_8f430a5f) -> None:
        """
        is invoked when the mouse enters a window.
        """
        ...
    @abstractmethod
    def mouseExited(self, e: MouseEvent_8f430a5f) -> None:
        """
        is invoked when the mouse exits a window.
        """
        ...
    @abstractmethod
    def mousePressed(self, e: MouseEvent_8f430a5f) -> None:
        """
        is invoked when a mouse button has been pressed on a window.
        
        Since mouse presses are usually also used to indicate requests for pop-up menus (also known as context menus) on objects, you might receive two events for a single mouse press: For example, if, on your operating system, pressing the right mouse button indicates the request for a context menu, then you will receive one call to mousePressed() indicating the mouse click, and another one indicating the context menu request. For the latter, the MouseEvent.PopupTrigger member of the event will be set to TRUE.
        """
        ...
    @abstractmethod
    def mouseReleased(self, e: MouseEvent_8f430a5f) -> None:
        """
        is invoked when a mouse button has been released on a window.
        """
        ...

__all__ = ['XMouseListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.presentation.animation_effect import AnimationEffect as AnimationEffect
from ...lo.presentation.animation_speed import AnimationSpeed as AnimationSpeed
from ...lo.presentation.chart_shape import ChartShape as ChartShape
from ...lo.presentation.click_action import ClickAction as ClickAction
from ...lo.presentation.custom_presentation import CustomPresentation as CustomPresentation
from ...lo.presentation.custom_presentation_access import CustomPresentationAccess as CustomPresentationAccess
from ...lo.presentation.date_time_shape import DateTimeShape as DateTimeShape
from ...lo.presentation.document_settings import DocumentSettings as DocumentSettings
from ...lo.presentation.draw_page import DrawPage as DrawPage
from ...lo.presentation.effect_commands import EffectCommands as EffectCommands
from ...lo.presentation.effect_node_type import EffectNodeType as EffectNodeType
from ...lo.presentation.effect_preset_class import EffectPresetClass as EffectPresetClass
from ...lo.presentation.fade_effect import FadeEffect as FadeEffect
from ...lo.presentation.footer_shape import FooterShape as FooterShape
from ...lo.presentation.graphic_object_shape import GraphicObjectShape as GraphicObjectShape
from ...lo.presentation.handout_shape import HandoutShape as HandoutShape
from ...lo.presentation.handout_view import HandoutView as HandoutView
from ...lo.presentation.header_shape import HeaderShape as HeaderShape
from ...lo.presentation.notes_shape import NotesShape as NotesShape
from ...lo.presentation.notes_view import NotesView as NotesView
from ...lo.presentation.ole2_shape import OLE2Shape as OLE2Shape
from ...lo.presentation.outline_view import OutlineView as OutlineView
from ...lo.presentation.outliner_shape import OutlinerShape as OutlinerShape
from ...lo.presentation.page_shape import PageShape as PageShape
from ...lo.presentation.paragraph_target import ParagraphTarget as ParagraphTarget
from ...lo.presentation.presentation import Presentation as Presentation
from ...lo.presentation.presentation2 import Presentation2 as Presentation2
from ...lo.presentation.presentation_document import PresentationDocument as PresentationDocument
from ...lo.presentation.presentation_range import PresentationRange as PresentationRange
from ...lo.presentation.presentation_view import PresentationView as PresentationView
from ...lo.presentation.preview_view import PreviewView as PreviewView
from ...lo.presentation.shape import Shape as Shape
from ...lo.presentation.shape_animation_sub_type import ShapeAnimationSubType as ShapeAnimationSubType
from ...lo.presentation.slide_number_shape import SlideNumberShape as SlideNumberShape
from ...lo.presentation.slide_show import SlideShow as SlideShow
from ...lo.presentation.slides_view import SlidesView as SlidesView
from ...lo.presentation.subtitle_shape import SubtitleShape as SubtitleShape
from ...lo.presentation.text_animation_type import TextAnimationType as TextAnimationType
from ...lo.presentation.title_text_shape import TitleTextShape as TitleTextShape
from ...lo.presentation.transition_factory import TransitionFactory as TransitionFactory
from ...lo.presentation.x_custom_presentation_supplier import XCustomPresentationSupplier as XCustomPresentationSupplier
from ...lo.presentation.x_handout_master_supplier import XHandoutMasterSupplier as XHandoutMasterSupplier
from ...lo.presentation.x_presentation import XPresentation as XPresentation
from ...lo.presentation.x_presentation2 import XPresentation2 as XPresentation2
from ...lo.presentation.x_presentation_page import XPresentationPage as XPresentationPage
from ...lo.presentation.x_presentation_supplier import XPresentationSupplier as XPresentationSupplier
from ...lo.presentation.x_shape_event_listener import XShapeEventListener as XShapeEventListener
from ...lo.presentation.x_slide_show import XSlideShow as XSlideShow
from ...lo.presentation.x_slide_show_controller import XSlideShowController as XSlideShowController
from ...lo.presentation.x_slide_show_listener import XSlideShowListener as XSlideShowListener
from ...lo.presentation.x_slide_show_view import XSlideShowView as XSlideShowView
from ...lo.presentation.x_transition import XTransition as XTransition
from ...lo.presentation.x_transition_factory import XTransitionFactory as XTransitionFactory



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .frame_action_event import FrameActionEvent as FrameActionEvent_ed700d5e

class XFrameActionListener(XEventListener_c7230c4a):
    """
    has to be provided if an object wants to receive events when several things happen to components within frames of the desktop frame tree.
    
    E.g., you can receive events of instantiation/destruction and activation/deactivation of components.

    See Also:
        `API XFrameActionListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XFrameActionListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XFrameActionListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XFrameActionListener'

    @abstractmethod
    def frameAction(self, Action: FrameActionEvent_ed700d5e) -> None:
        """
        is called whenever any action occurs to a component within a frame.
        """
        ...

__all__ = ['XFrameActionListener']


